@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdcontour.c 19521 2017-12-27 22:38:24Z pwessel $
+ *	$Id$
  *
- *	Copyright (c) 1991-2018 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2019 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -345,7 +345,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GRDCONTOUR_CTRL *Ctrl, struct
 				}
 				else if (opt->arg[0] == '-')
 					Ctrl->A.mode = 1;	/* Turn off all labels */
-				else if (opt->arg[0] == '+' && (isdigit(opt->arg[1]) || opt->arg[1] == '.')) {
+				else if (opt->arg[0] == '+' && (isdigit(opt->arg[1]) || strchr ("-+.", opt->arg[1]))) {
 					Ctrl->A.single_cont = atof (&opt->arg[1]);
 					Ctrl->contour.annot = true;
 				}
@@ -368,7 +368,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GRDCONTOUR_CTRL *Ctrl, struct
 					gmt_M_str_free (Ctrl->C.file);
 					Ctrl->C.file = strdup (opt->arg);
 				}
-				else if (opt->arg[0] == '+')
+				else if (opt->arg[0] == '+' && (isdigit(opt->arg[1]) || strchr ("-+.", opt->arg[1])))
 					Ctrl->C.single_cont = atof (&opt->arg[1]);
 				else
 					Ctrl->C.interval = atof (opt->arg);
@@ -466,7 +466,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GRDCONTOUR_CTRL *Ctrl, struct
 			case 'W':	/* Pen settings */
 				Ctrl->W.active = true;
 				k = reset = 0;
-				if (strchr ("-+", opt->arg[0])) {	/* Definitively old-style args */
+				if (opt->arg[0] == '-' || (opt->arg[0] == '+' && opt->arg[1] != 'c')) {	/* Definitively old-style args */
 					if (opt->arg[k] == '+') Ctrl->W.cptmode = 1, k++;
 					if (opt->arg[k] == '-') Ctrl->W.cptmode = 3, k++;
 					j = (opt->arg[k] == 'a' || opt->arg[k] == 'c') ? k+1 : k;
@@ -478,12 +478,14 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GRDCONTOUR_CTRL *Ctrl, struct
 							case 'f': Ctrl->W.cptmode = 2; break;
 							default:  Ctrl->W.cptmode = 3; break;
 						}
+						if (!strncmp (&c[2], "lf", 2U) || !strncmp (&c[2], "fl", 2U))	/* Catch any odd +clf or +cfl modifiers */
+							Ctrl->W.cptmode = 3;
 						c[0] = 0;	/* Temporarily chop of */
 						reset = 1;
 					}
 					j = (opt->arg[0] == 'a' || opt->arg[0] == 'c') ? k+1 : k;
 				}
-				if (j == k) {	/* Set both */
+				if (j == k && opt->arg[j]) {	/* Set both */
 					if (gmt_getpen (GMT, &opt->arg[j], &Ctrl->W.pen[0])) {
 						gmt_pen_syntax (GMT, 'W', " ", 0);
 						n_errors++;
@@ -491,7 +493,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct GRDCONTOUR_CTRL *Ctrl, struct
 					else
 						Ctrl->W.pen[1] = Ctrl->W.pen[0];
 				}
-				else {	/* Gave a or c.  Because the user may say -Wcyan we must prevent this from being seen as -Wc and color yan! */
+				else if (opt->arg[j]) {	/* Gave a or c.  Because the user may say -Wcyan we must prevent this from being seen as -Wc and color yan! */
 					/* Get the argument following a or c and up to first comma, slash (or to the end) */
 					n = k+1;
 					while (!(opt->arg[n] == ',' || opt->arg[n] == '/' || opt->arg[n] == '\0')) n++;
@@ -657,9 +659,17 @@ GMT_LOCAL void grd_sort_and_plot_ticks (struct GMT_CTRL *GMT, struct PSL_CTRL *P
 			while (!done && col <= stop) {
 				this_lon = gmt_M_grd_col_to_x (GMT, col, G->header);	/* Current longitude */
 				inside = gmt_non_zero_winding (GMT, this_lon, this_lat, save[pol].x, save[pol].y, np);
-				if (inside == 2)	/* OK, this point is inside */
-					done = true;
-				else
+				/* Worry about this point being ~exactly on the border but returned inside = 2, but
+				 * the grid node will be exactly the contour value and then fail the assignment of high
+				 * below.  We therefore check if the value is not equal to the contour value as well */
+				if (inside == 2) {	/* Might be inside */
+					ij = gmt_M_ijp (G->header, row, col);
+					if (!doubleAlmostEqual (G->data[ij], save[pol].cval))	/* OK, this point is truly inside */
+						done = true;
+					else	/* March along to the next point */
+						col++;
+				}
+				else	/* March along to the next point */
 					col++;
 			}
 			if (!done) continue;	/* Failed to find an inside point */
@@ -1105,7 +1115,10 @@ int GMT_grdcontour (void *V_API, int mode, void *args) {
 			}
 			contour[n_contours] = c * Ctrl->C.interval;
 			if (Ctrl->contour.annot && (contour[n_contours] - aval) > GMT_CONV4_LIMIT) aval += Ctrl->A.interval;
-			cont_type[n_contours] = (fabs (contour[n_contours] - aval) < GMT_CONV4_LIMIT) ? 'A' : 'C';
+			if (Ctrl->A.mode)	/* No labels */
+				cont_type[n_contours] = 'C';
+			else
+				cont_type[n_contours] = (fabs (contour[n_contours] - aval) < GMT_CONV4_LIMIT) ? 'A' : 'C';
 			cont_angle[n_contours] = (Ctrl->contour.angle_type == 2) ? Ctrl->contour.label_angle : GMT->session.d_NaN;
 			cont_do_tick[n_contours] = (char)Ctrl->T.active;
 		}
@@ -1236,10 +1249,9 @@ int GMT_grdcontour (void *V_API, int mode, void *args) {
 
 		Ctrl->contour.line_pen = Ctrl->W.pen[id];	/* Load current pen into contour structure */
 		if (Ctrl->W.cpt_effect) {
-			if (Ctrl->W.cptmode & 1) {	/* Override pen color according to CPT */
-				gmt_get_rgb_from_z (GMT, P, cval, rgb);
+			gmt_get_rgb_from_z (GMT, P, cval, rgb);
+			if (Ctrl->W.cptmode & 1)	/* Override pen color according to CPT */
 				gmt_M_rgb_copy (&Ctrl->contour.line_pen.rgb, rgb);
-			}
 			if (Ctrl->W.cptmode & 2)	/* Override label color according to CPT */
 				gmt_M_rgb_copy (&Ctrl->contour.font_label.fill.rgb, rgb);
 		}
