@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdconvert.c 19521 2017-12-27 22:38:24Z pwessel $
+ *	$Id$
  *
- *	Copyright (c) 1991-2018 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2019 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -260,7 +260,7 @@ int GMT_grdconvert (void *V_API, int mode, void *args) {
 	/* When converting from netcdf to netcdf, we will keep the old command, so we need to make a copy of it now */
 	command[0] = '\n';	command[1] = '\t';
 	strcat(command, "(old cmd) ");
-	strcat(command, Grid->header->command);
+	strncat (command, Grid->header->command, GMT_GRID_COMMAND_LEN320-13);
 
 	gmt_grd_init (GMT, Grid->header, options, true);
 
