@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psrose.c 19521 2017-12-27 22:38:24Z pwessel $
+ *	$Id$
  *
- *	Copyright (c) 1991-2018 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2019 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -35,7 +35,7 @@
 #define THIS_MODULE_NAME	"psrose"
 #define THIS_MODULE_LIB		"core"
 #define THIS_MODULE_PURPOSE	"Plot a polar histogram (rose, sector, windrose diagrams)"
-#define THIS_MODULE_KEYS	"<D{,CD(,>X}"
+#define THIS_MODULE_KEYS	"<D{,CC(,ED(,>X},>D),>DI@<D{,ID),CC("
 #define THIS_MODULE_NEEDS	"RJ"
 #define THIS_MODULE_OPTIONS "-:>BKOPRUVXYbdehipstxy" GMT_OPT("Ec")
 
@@ -787,7 +787,7 @@ int GMT_psrose (void *V_API, int mode, void *args) {
 		}
 	}
 
-	if (sector_plot && !Ctrl->A.rose && Ctrl->G.fill.rgb[0] >= 0) {	/* Draw pie slices for sector plot if fill is requested */
+	if (sector_plot && !Ctrl->A.rose && Ctrl->G.active) {	/* Draw pie slices for sector plot if fill is requested */
 
 		gmt_setfill (GMT, &(Ctrl->G.fill), false);
 		for (bin = 0; bin < n_bins; bin++) {
